(sec:api)=
# API reference

## Efficient loglikelihood evaluation

```{eval-rst}
.. autofunction:: tripy.loglikelihood.chol_loglike_1D
.. autofunction:: tripy.loglikelihood.chol_loglike_2D
.. autofunction:: tripy.loglikelihood.kron_loglike_temporal
.. autofunction:: tripy.loglikelihood.kron_loglike_2D_tridiag
.. autofunction:: tripy.loglikelihood.kron_loglike_ND_tridiag
.. autofunction:: tripy.loglikelihood.log_likelihood_linear_normal
```

## Sampling from high-dimensional distributions

```{eval-rst}
.. autofunction:: tripy.sampling.chol_sample_1D
.. autofunction:: tripy.sampling.kron_sample_2D
.. autofunction:: tripy.sampling.kron_sample_ND
```
